"""
.. currentmodule:: flytekitplugins.wandb

This package contains things that are useful when extending Flytekit.

.. autosummary::
   :template: custom.rst
   :toctree: generated/

   wandb_init
"""

from .tracking import wandb_init

__all__ = ["wandb_init"]
